@@ -86,7 +86,7 @@ class AsIsNode: public Node {
       Rf_error("Invalid target type for AsIsNode copy_into");
     }
     for (R_xlen_t i = start; i < end; i++) {
-      SET_VECTOR_ELT(target, i, Rf_lazy_duplicate(obj));
+      SET_VECTOR_ELT(target, i, Rf_shallow_duplicate(obj));
     }
   }
 };
