@@ -42,7 +42,7 @@ void fill_vector(SEXP source, SEXP target, R_xlen_t from, R_xlen_t to) {
      REP(from, to, n, i, j, SET_STRING_ELT(target, i, STRING_ELT(source, j));); break;
    case VECSXP:
    case EXPRSXP:
-     REP(from, to, n, i, j, SET_VECTOR_ELT(target, i, Rf_lazy_duplicate(VECTOR_ELT(source, j))););
+     REP(from, to, n, i, j, SET_VECTOR_ELT(target, i, Rf_shallow_duplicate(VECTOR_ELT(source, j))););
      break;
    default:
      Rf_error("Cannot unnest lists with elements of type %s", Rf_type2char(TYPEOF(source)));
@@ -87,7 +87,7 @@ void fill_vector_1(SEXP source, R_xlen_t source_ix, SEXP target, R_xlen_t from,
    case VECSXP:
    case EXPRSXP: {
      SEXP val = VECTOR_ELT(source, source_ix);
-     REP1(from, to, i, SET_VECTOR_ELT(target, i, Rf_lazy_duplicate(val)););
+     REP1(from, to, i, SET_VECTOR_ELT(target, i, Rf_shallow_duplicate(val)););
    }; break;
    default:
      Rf_error("Cannot unnest lists with elements of type %s", Rf_type2char(TYPEOF(source)));
